domain/chemistry library

Quantity types, units and constants commonly encountered in the field of chemistry.

Classes

AmountOfSubstance
The size of an ensemble of elementary entities, such as atoms, molecules, electrons, and other particles. See the Wikipedia entry for Amount of substance for more information.
AmountOfSubstanceUnits
Units acceptable for use in describing AmountOfSubstance quantities.
Concentration
The abundance of a constituent divided by the total volume of a mixture. See the Wikipedia entry for Concentration for more information.
ConcentrationUnits
Units acceptable for use in describing Concentration quantities.
MassDensity
Mass per unit volume. See the Wikipedia entry for Density for more information.
MassDensityUnits
Units acceptable for use in describing MassDensity quantities.
MolarEnergy
Energy per mole of a substance. See the Wikipedia entry for Specific energy for more information.
MolarEnergyUnits
Units acceptable for use in describing MolarEnergy quantities.
MolarEntropy
Entropy content per mole of substance. See the Wikipedia entry for Standard molar entropy for more information.
MolarEntropyUnits
Units acceptable for use in describing MolarEntropy quantities.
Volume
The amount of three-dimensional space enclosed by some closed boundary. See the Wikipedia entry for Volume for more information.
VolumeUnits
Units acceptable for use in describing Volume quantities.

Constants

atomicMass → const Mass
One twelfth of the mass of a carbon-12 atom in its nuclear and electronic ground state.
avogadro → const MiscQuantity
Avogadro's Number ('NA' or 'L')
faradayConstant → const MiscQuantity
Faraday constant ('F')
gasConstantMolar → const MolarEntropy
Molar Gas Constant ('R')
loschmidtStdAtm → const MiscQuantity
Locshmidt Constant ('n0') at 273.15 K and 101.325 kPa

Properties

moles AmountOfSubstanceUnits
A synonym for the SI-MKS base unit of amount of substance.
final