domain/fluid_dynamics library

Quantity types, units and constants commonly encountered in fluid dynamics and hydraulics.

Classes

DynamicViscosity
A measure of a fluid's resistance to gradual deformation by shear stress or tensile stress. See the Wikipedia entry for Viscosity for more information.
DynamicViscosityUnits
Units acceptable for use in describing DynamicViscosity quantities.
KinematicViscosity
The resistance to flow of a fluid, equal to its absolute viscosity divided by its density. See the Wikipedia entry for Viscosity for more information.
KinematicViscosityUnits
Units acceptable for use in describing KinematicViscosity quantities.
MassDensity
Mass per unit volume. See the Wikipedia entry for Density for more information.
MassDensityUnits
Units acceptable for use in describing MassDensity quantities.
MassFlowRate
The mass of a substance which passes per unit of time. See the Wikipedia entry for Mass flow rate for more information.
MassFlowRateUnits
Units acceptable for use in describing MassFlowRate quantities.
Pressure
Force applied perpendicular to the surface of an object per unit area over which that force is distributed. See the Wikipedia entry for Pressure for more information.
PressureUnits
Units acceptable for use in describing Pressure quantities.
Speed
The rate of change of position. See the Wikipedia entry for Speed for more information.
SpeedUnits
Units acceptable for use in describing Speed quantities.
VolumeFlowRate
The volume of fluid which passes per unit time. See the Wikipedia entry for Volumetric flow rate for more information.
VolumeFlowRateUnits
Units acceptable for use in describing VolumeFlowRate quantities.

Properties

centistokes KinematicViscosityUnits
Centistokes as a unit.
getter/setter pair
stokes KinematicViscosityUnits
Stokes as a unit.
getter/setter pair