adjustForExponent method

String adjustForExponent(
  1. String str
)

Subclasses should override if they wish to modify the number string to include an exponent and move the decimal point.

Implementation

String adjustForExponent(String str) => str;