symbols property
Return the symbols which are used in our locale. Cache them to avoid repeated lookup.
Implementation
@override
// TODO: implement symbols
NumberSymbols get symbols => throw UnimplementedError();
Return the symbols which are used in our locale. Cache them to avoid repeated lookup.
@override
// TODO: implement symbols
NumberSymbols get symbols => throw UnimplementedError();