operator + method
Returns the sum of this Quantity and addend.
- If an attempt is made to add two Quantity objects having different dimensions, this method will throw a DimensionsException.
- If the uncertainty is calculated it will be equal to the combined standard uncertainty divided by the absolute value of the sum of the quantities. The standard uncertainty is the square root of the sum of the squares of the two quantities' standard uncertainties. See (NIST Reference on Constants, Units, and Uncertainty: Combining Uncertainty Components](http://physics.nist.gov/cuu/Uncertainty/combination.html))
Implementation
@override
Quantity operator +(dynamic addend) {
if (addend is PowerLevel) {
return PowerLevel.inUnits(
0.5 * math.log(ratio + addend.ratio), Level.nepers);
} else {
return super + addend;
}
}