domain/acoustics library
Quantity types, units and constants commonly encountered in acoustics.
Classes
- Frequency
- The number of occurrences of a repeating event per unit time. See the Wikipedia entry for Frequency for more information.
- FrequencyUnits
- Units acceptable for use in describing Frequency quantities.
- Level
- Represents logarithmic physical quantities and has dimensions of 1 (Scalar). Level of a field quantity and level of a power quantity are two common logarithmic quantities.
- LevelUnits
- Units acceptable for use in describing Level quantities.
- Power
- Amount of energy per unit time. See the Wikipedia entry for Power (physics) for more information.
- PowerUnits
- Units acceptable for use in describing Power quantities.
- Pressure
- Force applied perpendicular to the surface of an object per unit area over which that force is distributed. See the Wikipedia entry for Pressure for more information.
- PressureUnits
- Units acceptable for use in describing Pressure quantities.
- Time
- Represents the time interval physical quantity (one of the seven base SI quantities).
- TimeUnits
- Units acceptable for use in describing Time quantities.