domain/atomic_nuclear library
Quantity types, units and constants commonly encountered in the fields of atomic, molecular, and nuclear physics.
Classes
- AbsorbedDose
- The mean energy imparted to matter per unit mass by ionizing radiation. See the Wikipedia entry for Absorbed Dose for more information.
- AbsorbedDoseUnits
- Units acceptable for use in describing AbsorbedDose quantities.
- Activity
- A measure of the effective concentration of a species in a mixture. See the Wikipedia entry for Thermodynamic activity for more information.
- ActivityUnits
- Units acceptable for use in describing Activity quantities.
- Area
- The extent of a two-dimensional figure or shape. See the Wikipedia entry for Area for more information.
- AreaUnits
- Units acceptable for use in describing Area quantities.
- Charge
- The property of matter that causes it to experience a force when placed in an electromagnetic field See the Wikipedia entry for Electric charge for more information.
- ChargeUnits
- Units acceptable for use in describing Charge quantities.
- DoseEquivalent
- Represents the stochastic health effects (probability of cancer induction and genetic damage) of ionizing radiation on the human body. See the Wikipedia entry for Equivalent dose for more information.
- DoseEquivalentUnits
- Units acceptable for use in describing DoseEquivalent quantities.
- Energy
- The ability of a system to perform work; cannot be created or destroyed but can take many forms. See the Wikipedia entry for Energy for more information.
- EnergyUnits
- Units acceptable for use in describing Energy quantities.
- Length
- Represents the length physical quantity (one of the seven base SI quantities). See the Wikipedia entry for Length for more information.
- LengthUnits
- Units acceptable for use in describing Length quantities.
- Mass
- Represents the mass physical quantity (one of the seven base SI quantities), that determines the strength of a body's mutual gravitational attraction to other bodies. See the Wikipedia entry for Mass for more information.
- MassUnits
- Units acceptable for use in describing Mass quantities.
Constants
- alphaParticleMass → const Mass
- The rest mass of a helium nucleus.
- atomicMass → const Mass
- One twelfth of the mass of a carbon-12 atom in its nuclear and electronic ground state.
- avogadro → const MiscQuantity
- Avogadro's Number ('NA' or 'L')
- bohrRadius → const Length
- The mean radius of the orbit of an electron around the nucleus of a hydrogen atom at its ground state.
- classicalElectronRadius → const Length
- The classical electron radius is a combination of fundamental physical quantities that define a length scale for problems involving an electron interacting with electromagnetic radiation.
- comptonWavelength → const Length
- The wavelength of a photon whose energy is the same as the mass energy equivalent of that particle.
- deuteronMass → const Mass
- The mass of a stationary deuteron.
- electronMass → const Mass
- The mass of a stationary electron.
- elementaryCharge → const Charge
- The electric charge carried by a single proton.
- faradayConstant → const MiscQuantity
- Faraday constant ('F')
- fineStructureConstant → const Scalar
- Fine structure constant (alpha).
- hBar → const AngularMomentum
- The Planck constant divided by 2 PI (a.k.a., 'h-bar' or 'reduced Planck constant').
- helionMass → const Mass
- The mass of a stationary helion.
- loschmidtStdAtm → const MiscQuantity
- Locshmidt Constant ('n0') at 273.15 K and 101.325 kPa
- muonMass → const Mass
- The mass of a stationary muon particle.
- neutronMass → const Mass
- The mass of a stationary neutron.
- planckConstant → const AngularMomentum
- The Planck constant.
- protonMass → const Mass
- The mass of a stationary proton.
- rydberg → const WaveNumber
- Appears in the Balmer formula for spectral lines of the hydrogen atom. For a hydrogen atom, the effective mass must be taken as the reduced mass of the proton and electron. In MKS, this gives the Rydberg constant.
- tauComptonWavelength → const Length
- The tau Compton wavelength.
- tauMass → const Mass
- The mass of a stationary tau particle.
Properties
- barns → AreaUnits
-
Accepted for use with the SI, subject to further review.
Equals 100 square femtometers, or 1.0e-28 square meters.
final
- electronVolts → EnergyUnits
-
Accepted for use with the SI.
final