domain/radiometry library
Quantity types, units and constants commonly encountered in the fields of radiometry and photometry.
Classes
- EnergyFlux
- The rate of transfer of energy through a surface. See the Wikipedia entry for Energy density for more information.
- EnergyFluxUnits
- Units acceptable for use in describing EnergyFlux quantities.
- HeatFluxDensity
- Heat rate per unit area. See the Wikipedia entry for Heat flux for more information.
- HeatFluxDensityUnits
- Units acceptable for use in describing HeatFluxDensity quantities.
- Illuminance
- The total luminous flux incident on a surface, per unit area. See the Wikipedia entry for Illuminance for more information.
- IlluminanceUnits
- Units acceptable for use in describing Illuminance quantities.
- Luminance
- The intensity of light emitted from a surface per unit area. See the Wikipedia entry for Luminance for more information.
- LuminanceUnits
- Units acceptable for use in describing Luminance quantities.
- LuminousFlux
- The perceived power of light. It differs from radiant flux, the measure of the total power of electromagnetic radiation (including infrared, ultraviolet, and visible light), in that luminous flux is adjusted to reflect the varying sensitivity of the human eye to different wavelengths of light See the Wikipedia entry for Luminance for more information.
- LuminousFluxUnits
- Units acceptable for use in describing LuminousFlux quantities.
- LuminousIntensity
- Represents the luminous intensity physical quantity (one of the seven base SI quantities), the wavelength-weighted power emitted by a light source in a particular direction per unit solid angle. See the Wikipedia entry for Luminous intensity for more information.
- LuminousIntensityUnits
- Units acceptable for use in describing LuminousIntensity quantities.
- Power
- Amount of energy per unit time. See the Wikipedia entry for Power (physics) for more information.
- PowerUnits
- Units acceptable for use in describing Power quantities.
- SpectralIrradiance
- Irradiance of a surface per unit frequency. See the Wikipedia entry for Radiometry for more information.
- SpectralIrradianceUnits
- Units acceptable for use in describing SpectralIrradiance quantities.
Constants
- firstRadiationConstant → const MiscQuantity
- First Radiation Constant ('c1')
- secondRadiationConstant → const MiscQuantity
- Second Radiation Constant ('c2')
- solarConstant → const EnergyFlux
- The mean solar electromagnetic radiation (the solar irradiance) per unit area that would be incident on a plane perpendicular to the rays, at a distance of one astronomical unit (AU) from the Sun.
- solarLuminosity → const Power
- The solar luminosity constant is the radiant flux (power emitted in the form of photons) emitted by the Sun (a typical value; the Sun's output actually varies slightly over time).
- stefanBoltzmann → const MiscQuantity
- Stefan-Boltzmann constant (sigma)
- wienDisplacement → const MiscQuantity
- Wien Displacement Law Constant ('b')
Properties
- candelas → LuminousIntensityUnits
-
The standard SI unit.
final
- janskys → SpectralIrradianceUnits
-
A non-SI unit of spectral irradiance used especially in radio astronomy.
final
- lux ↔ IlluminanceUnits
-
The standard SI unit.
getter/setter pair
- watts ↔ PowerUnits
-
The standard SI unit.
getter/setter pair